"""SpellChecker Module"""

from spellchecker.info import (  # noqa: F401
    __author__,
    __bugtrack_url__,
    __credits__,
    __email__,
    __license__,  # noqa: F401
    __maintainer__,
    __url__,
    __version__,
)
from spellchecker.spellchecker import SpellChecker, WordFrequency

__all__ = ["SpellChecker", "WordFrequency"]
